@@ -16,9 +16,9 @@
 
 # Test to make sure rules to invoke all compilers are selected with
 # mixed source objects.
-# (copied from compile_f_c_cxx.sh) Mike Nolta <mrnolta@princeton.edu>
+# (copied from compile_f_c_cxx.test) Mike Nolta <mrnolta@princeton.edu>
 
-. test-init.sh
+. ./defs || Exit 1
 
 cat >> configure.ac << 'END'
 AC_PROG_CC
