@@ -17,7 +17,7 @@
 # Minimal test of Java functionality.
 
 required=javac
-. test-init.sh
+. ./defs || Exit 1
 
 cat >>configure.ac <<'EOF'
 AC_OUTPUT
@@ -34,12 +34,19 @@ $AUTOMAKE
 
 $EGREP '\.stamp|class' Makefile.in # For debugging.
 grep '^all[-a-z]*:.*classjava\.stamp' Makefile.in
-test $(grep -c '^all[-a-z]*:.*classjava\.stamp' Makefile.in) -eq 1
+test `grep -c '^all[-a-z]*:.*classjava\.stamp' Makefile.in` -eq 1
 
-echo 'class a { }' > a.java
-echo 'class b { }' > b.java
+cat >a.java <<EOF
+class a
+{
+}
+EOF
 
-./configure
+cat >b.java <<EOF
+class b
+{
+}
+EOF
+
+./configure --prefix "`pwd`"
 $MAKE distcheck
-
-:
