@@ -18,7 +18,7 @@
 # are used, even when dependency tracking is disabled.
 
 required='cc lex'
-. test-init.sh
+. ./defs || Exit 1
 
 cat >>configure.ac <<\END
 AC_PROG_CC
