@@ -19,7 +19,7 @@
 # Report from Harlan Stenn.
 
 required='libtoolize'
-. test-init.sh
+. ./defs || Exit 1
 
 cat >>configure.ac <<'END'
 AM_CONDITIONAL([COND1], [true])
