@@ -17,16 +17,18 @@
 # Long lines should be wrapped.
 # Report from Albert Chin.
 
-. test-init.sh
+. ./defs || Exit 1
 
-n=1 files= match=
+n=1
+files=
+match=
 while test $n -le 100
 do
   files="$files filename$n"
   match="..........$match"
-  n=$(($n + 1))
+  n=`expr $n + 1`
 done
-files2=$(echo "$files" | sed s/filename/filenameb/g)
+files2=`echo "$files" | sed s/filename/filenameb/g`
 
 cat >Makefile.am <<EOF
 FOO = $files $files2 \
@@ -42,7 +44,5 @@ EOF
 $ACLOCAL
 $AUTOMAKE
 
-grep $match Makefile.in && exit 1
+grep $match Makefile.in && Exit 1
 grep 'filenameb100 grepme' Makefile.in
-
-:
