@@ -19,7 +19,6 @@
 # with the Automake test harness".
 
 am_create_testdir=empty
-am_parallel_tests=yes
 . ./defs || Exit 1
 
 cat > Makefile.am <<'END'
@@ -137,4 +136,6 @@ echo AM_TEST_LOG_DRIVER_FLAGS = --ignore-exit >> Makefile.in
 ./config.status Makefile
 $MAKE distcheck
 
+rm -f Makefile.in # To avoid a maintainer-check failure.
+
 :
