@@ -18,9 +18,9 @@
 #  - normalization of whitespace in console testsuite progress associated
 #    with TODO and SKIP directives
 
-. test-init.sh
+. ./defs || Exit 1
 
-. tap-setup.sh
+. "$am_testauxdir"/tap-setup.sh || fatal_ "sourcing tap-setup.sh"
 
 cat > stub.tap <<END
 1 # TODO
