@@ -18,7 +18,7 @@
 # from Johan Danielsson (and a very nice bug report, too, I might
 # add).
 
-. test-init.sh
+. ./defs || Exit 1
 
 cat >> configure.ac << 'END'
 WHO_AM_I=17
