@@ -17,7 +17,7 @@
 # Removal recovery rules for headers should not remove files with 'make -n'.
 
 required='cc yacc'
-. test-init.sh
+. ./defs || Exit 1
 
 cat >> configure.ac << 'END'
 AC_PROG_CC
@@ -53,6 +53,6 @@ $MAKE
 rm -f parse.h
 $MAKE -n parse.h
 test -f parse.c
-test ! -e parse.h
+test ! -f parse.h
 
 :
